@@ -15,9 +15,10 @@ from pathlib import Path
 
 from .baseplatformtests import BasePlatformTests
 from .helpers import is_ci
-from mesonbuild.mesonlib import EnvironmentVariables, ExecutableSerialisation, MesonException, is_linux, python_command
-from mesonbuild.mformat import match_path
+from mesonbuild.mesonlib import EnvironmentVariables, ExecutableSerialisation, MesonException, is_linux, python_command, windows_proof_rmtree
+from mesonbuild.mformat import Formatter, match_path
 from mesonbuild.optinterpreter import OptionInterpreter, OptionException
+from mesonbuild.options import OptionStore
 from run_tests import Backend
 
 @skipIf(is_ci() and not is_linux(), "Run only on fast platforms")
@@ -31,11 +32,12 @@ class PlatformAgnosticTests(BasePlatformTests):
         Tests that find_program() with a relative path does not find the program
         in current workdir.
         '''
-        testdir = os.path.join(self.unit_test_dir, '101 relative find program')
+        testdir = os.path.join(self.unit_test_dir, '100 relative find program')
         self.init(testdir, workdir=testdir)
 
     def test_invalid_option_names(self):
-        interp = OptionInterpreter('')
+        store = OptionStore()
+        interp = OptionInterpreter(store, '')
 
         def write_file(code: str):
             with tempfile.NamedTemporaryFile('w', dir=self.builddir, encoding='utf-8', delete=False) as f:
@@ -68,7 +70,8 @@ class PlatformAgnosticTests(BasePlatformTests):
 
     def test_option_validation(self):
         """Test cases that are not catch by the optinterpreter itself."""
-        interp = OptionInterpreter('')
+        store = OptionStore()
+        interp = OptionInterpreter(store, '')
 
         def write_file(code: str):
             with tempfile.NamedTemporaryFile('w', dir=self.builddir, encoding='utf-8', delete=False) as f:
@@ -88,11 +91,11 @@ class PlatformAgnosticTests(BasePlatformTests):
                                interp.process, fname)
 
     def test_python_dependency_without_pkgconfig(self):
-        testdir = os.path.join(self.unit_test_dir, '103 python without pkgconfig')
+        testdir = os.path.join(self.unit_test_dir, '102 python without pkgconfig')
         self.init(testdir, override_envvars={'PKG_CONFIG': 'notfound'})
 
     def test_debug_function_outputs_to_meson_log(self):
-        testdir = os.path.join(self.unit_test_dir, '105 debug function')
+        testdir = os.path.join(self.unit_test_dir, '104 debug function')
         log_msg = 'This is an example debug output, should only end up in debug log'
         output = self.init(testdir)
 
@@ -334,6 +337,60 @@ class PlatformAgnosticTests(BasePlatformTests):
         for filename, pattern, expected in cases:
             self.assertTrue(match_path(filename, pattern) is expected, f'{filename} -> {pattern}')
 
+    def test_format_invalid_config_key(self) -> None:
+        fd, fname = tempfile.mkstemp(suffix='.ini', text=True)
+        self.addCleanup(os.unlink, fname)
+
+        with os.fdopen(fd, 'w', encoding='utf-8') as handle:
+            handle.write('not_an_option = 42\n')
+
+        with self.assertRaises(MesonException):
+            Formatter(Path(fname), use_editor_config=False, fetch_subdirs=False)
+
+    def test_format_invalid_config_value(self) -> None:
+        fd, fname = tempfile.mkstemp(suffix='.ini', text=True)
+        self.addCleanup(os.unlink, fname)
+
+        with os.fdopen(fd, 'w', encoding='utf-8') as handle:
+            handle.write('max_line_length = string\n')
+
+        with self.assertRaises(MesonException):
+            Formatter(Path(fname), use_editor_config=False, fetch_subdirs=False)
+
+    def test_format_invalid_editorconfig_value(self) -> None:
+        dirpath = tempfile.mkdtemp()
+        self.addCleanup(windows_proof_rmtree, dirpath)
+
+        editorconfig = Path(dirpath, '.editorconfig')
+        with open(editorconfig, 'w', encoding='utf-8') as handle:
+            handle.write('[*]\n')
+            handle.write('indent_size = string\n')
+
+        formatter = Formatter(None, use_editor_config=True, fetch_subdirs=False)
+        with self.assertRaises(MesonException):
+            formatter.load_editor_config(editorconfig)
+
+    def test_format_empty_file(self) -> None:
+        formatter = Formatter(None, use_editor_config=False, fetch_subdirs=False)
+        for code in ('', '\n'):
+            formatted = formatter.format(code, Path())
+            self.assertEqual('\n', formatted)
+    
+    def test_format_indent_comment_in_brackets(self) -> None:
+        """Ensure comments in arrays and dicts are correctly indented"""
+        formatter = Formatter(None, use_editor_config=False, fetch_subdirs=False)
+        code = 'a = [\n    # comment\n]\n'
+        formatted = formatter.format(code, Path())
+        self.assertEqual(code, formatted)
+        
+        code = 'a = [\n    # comment\n    1,\n]\n'
+        formatted = formatter.format(code, Path())
+        self.assertEqual(code, formatted)
+
+        code = 'a = {\n    # comment\n}\n'
+        formatted = formatter.format(code, Path())
+        self.assertEqual(code, formatted)
+        
     def test_error_configuring_subdir(self):
         testdir = os.path.join(self.common_test_dir, '152 index customtarget')
         out = self.init(os.path.join(testdir, 'subdir'), allow_fail=True)
